#pragma once
#include "core/tool_data.hpp"

namespace horizon {
class ToolDataPoolUpdated : public ToolData {};
} // namespace horizon
